diff options
| author | Rosen Penev <rosenp@gmail.com> | 2020-07-18 16:16:51 -0700 |
|---|---|---|
| committer | Rosen Penev <rosenp@gmail.com> | 2020-07-18 16:43:27 -0700 |
| commit | c639477965d5356a3354ccd1a9ac3db6270f0ac9 (patch) | |
| tree | ceb8c5b3fb46a334090cbef5d1b61fc2ddb8d498 /lang/python/python-lxml | |
| parent | aaa81d753424aa0d7e0a618e733bc2062cdd6530 (diff) | |
liblz4: convert to meson
Faster compilation
Before:
Executed in 13.68 secs fish external
usr time 12.51 secs 0.00 micros 12.51 secs
sys time 1.78 secs 345.00 micros 1.78 secs
After:
Executed in 9.60 secs fish external
usr time 10.66 secs 281.00 micros 10.66 secs
sys time 1.39 secs 36.00 micros 1.39 secs
Signed-off-by: Rosen Penev <rosenp@gmail.com>
Diffstat (limited to 'lang/python/python-lxml')
0 files changed, 0 insertions, 0 deletions
